custom,
String rawContent
) {
- private static final Logger LOGGER = LoggerFactory.getLogger(Post.class);
+ private static final Logger LOGGER = LoggerFactory.getLogger(Article.class);
/**
- * Creates a {@link Post} instance by reading and parsing the content of a post file.
+ * Creates a {@link Article} instance by reading and parsing the content of an article file.
*
* The method extracts metadata properties, content, and versioning information
* based on the Git history of the file.
*
* @param git the Git repository used to retrieve versioning and commit information
- * @param path the relative path to the file within the "posts" directory
- * @return a {@link Post} object populated with data extracted from the specified file
+ * @param path the relative path to the file within the "articles" directory
+ * @return a {@link Article} object populated with data extracted from the specified file
* @throws IOException if an error occurs during file reading
*/
- public static Post fromFile(Git git, Path path) throws IOException {
+ public static Article fromFile(Git git, Path path) throws IOException {
/* read properties before filtering */
var slug = path.getFileName().toString().split("\\.")[0];
- path = Path.of("posts").resolve(path);
+ path = Path.of("articles").resolve(path);
var lines = Files.readAllLines(git.getRepository().getDirectory().toPath().getParent().resolve(path));
var properties = new HashMap();
@@ -81,7 +81,7 @@ public record Post(
break;
if (properties.putIfAbsent(key, data) != null)
- LOGGER.warn("[Post {}] Ignoring duplicate property: {}", slug, key);
+ LOGGER.warn("[Article {}] Ignoring duplicate property: {}", slug, key);
}
var content = String.join("\n", lines).strip();
@@ -132,18 +132,9 @@ public record Post(
}
} catch (GitAPIException e) {
draft = true;
- LOGGER.warn("[Post {}] Draft because of a Git exception: {}", slug, e.getMessage());
+ LOGGER.warn("[Article {}] Draft because of a Git exception: {}", slug, e.getMessage());
}
- return new Post(slug, title, summary, draft, revisions, createdBy, createdAt, modifiedBy, modifiedAt, custom, content);
- }
-
- /**
- * Retrieves the raw HTML content associated with the post.
- *
- * @return the raw HTML content as a string
- */
- public String htmlContent() {
- return rawContent;
+ return new Article(slug, title, summary, draft, revisions, createdBy, createdAt, modifiedBy, modifiedAt, custom, content);
}
}
diff --git a/src/main/java/eu/m724/blog/object/Site.java b/src/main/java/eu/m724/blog/object/Site.java
index 6bc21ca..ceb4f20 100644
--- a/src/main/java/eu/m724/blog/object/Site.java
+++ b/src/main/java/eu/m724/blog/object/Site.java
@@ -12,7 +12,6 @@ import org.snakeyaml.engine.v2.api.LoadSettings;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
-import java.util.HashMap;
import java.util.Map;
/**
@@ -21,6 +20,7 @@ import java.util.Map;
* @param name the name of the site
* @param baseUrl the base URL of the site
* @param directory The directory that the site is installed into. Like "https://example.com/blog" turns to "/blog"
+ * @param templateArticles whether to parse posts with Pebble templating
* @param custom a map of additional custom properties
*/
public record Site(
@@ -29,6 +29,8 @@ public record Site(
String directory,
+ boolean templateArticles,
+
Map custom
) {
/**
@@ -43,33 +45,21 @@ public record Site(
var load = new Load(LoadSettings.builder().build());
var yaml = (Map) load.loadFromInputStream(Files.newInputStream(path));
- String name = null;
- String baseUrl = null;
- var custom = new HashMap();
+ String name = (String) yaml.get("name");
+ String baseUrl = (String) yaml.getOrDefault("baseUrl", "/");
+ var templateArticles = (boolean) yaml.getOrDefault("templateArticles", false);
- for (var key : yaml.keySet()) {
- var value = yaml.get(key);
-
- switch (key) {
- case "name":
- name = (String) value;
- break;
- case "baseUrl":
- baseUrl = (String) value;
- break;
- default:
- custom.put(key, value);
+ String directory = "/";
+ if (baseUrl != null) {
+ var temp = baseUrl.substring(baseUrl.indexOf(':') + 3);
+ var slashIndex = temp.indexOf('/');
+ if (slashIndex != -1) {
+ directory += temp.substring(slashIndex + 1) + "/";
}
}
- String directory = null;
- if (baseUrl != null) {
- var temp = baseUrl.substring(baseUrl.indexOf(':') + 3);
- directory = temp.substring(temp.indexOf('/'));
- }
-
return new Site(
- name, baseUrl, directory, custom
+ name, baseUrl, directory, templateArticles, yaml
);
}
}
diff --git a/src/main/java/eu/m724/blog/template/TemplateExtension.java b/src/main/java/eu/m724/blog/template/TemplateExtension.java
index dc5ae12..2130623 100644
--- a/src/main/java/eu/m724/blog/template/TemplateExtension.java
+++ b/src/main/java/eu/m724/blog/template/TemplateExtension.java
@@ -43,7 +43,7 @@ public class TemplateExtension extends AbstractExtension {
path = CacheBuster.insertHashInPath(path, hash);
}
- return site.directory() + "/" + path;
+ return site.directory() + path;
}
},
"asset", new Function() {
@@ -61,10 +61,15 @@ public class TemplateExtension extends AbstractExtension {
path = CacheBuster.insertHashInPath(path, hash);
}
- return site.directory() + "/" + path;
+ return site.directory() + path;
}
}
// TODO make url_for that supports relative and absolute paths
);
}
+
+ @Override
+ public Map getGlobalVariables() {
+ return Map.of("site", site);
+ }
}
diff --git a/src/main/java/eu/m724/blog/template/TemplateRenderer.java b/src/main/java/eu/m724/blog/template/TemplateRenderer.java
index de25e11..144fbc7 100644
--- a/src/main/java/eu/m724/blog/template/TemplateRenderer.java
+++ b/src/main/java/eu/m724/blog/template/TemplateRenderer.java
@@ -6,7 +6,7 @@
package eu.m724.blog.template;
-import eu.m724.blog.object.Post;
+import eu.m724.blog.object.Article;
import eu.m724.blog.object.Site;
import io.pebbletemplates.pebble.PebbleEngine;
import io.pebbletemplates.pebble.loader.FileLoader;
@@ -24,6 +24,8 @@ import java.util.Map;
*/
public class TemplateRenderer {
private final Site site;
+
+ private final PebbleEngine pebbleEngine;
private final PebbleTemplate indexTemplate, articleTemplate;
/**
@@ -38,7 +40,7 @@ public class TemplateRenderer {
loader.setPrefix(templateDirectory.toString());
loader.setSuffix(".html");
- var pebbleEngine = new PebbleEngine.Builder()
+ this.pebbleEngine = new PebbleEngine.Builder()
.loader(loader)
.extension(new TemplateExtension(site, fileHashes))
.build();
@@ -51,37 +53,47 @@ public class TemplateRenderer {
/**
* Renders the index page using this template.
*
- * @param posts the {@link Post}s to be included in the index page
+ * @param articles the {@link Article}s to be included in the index page
* @return the rendered index HTML page as a string
* @throws IOException if an error occurs during the template evaluation
*/
- public String renderIndex(List posts) throws IOException {
- Map context = Map.of(
- "site", site,
- "articles", posts
+ public String renderIndex(List articles) throws IOException {
+ var context = Map.of(
+ "articles", articles
);
- var writer = new StringWriter();
- indexTemplate.evaluate(writer, context);
-
- return writer.toString();
+ return renderTemplate(indexTemplate, context);
}
/**
* Renders the content of a post using this template.
*
- * @param post the {@link Post} to be rendered
+ * @param article the {@link Article} to be rendered
* @return the rendered post HTML page as a string
* @throws IOException if an error occurs during template evaluation
*/
- public String renderPost(Post post) throws IOException {
- Map context = Map.of(
- "site", site,
- "article", post
+ public String renderArticle(Article article) throws IOException {
+ String content = article.rawContent();
+
+ if (site.templateArticles()) {
+ var context = Map.of(
+ "article", article
+ );
+
+ content = renderTemplate(pebbleEngine.getLiteralTemplate(content), context);
+ }
+
+ var context = Map.of(
+ "article", article,
+ "content", content
);
+ return renderTemplate(articleTemplate, context);
+ }
+
+ private String renderTemplate(PebbleTemplate template, Map context) throws IOException {
var writer = new StringWriter();
- articleTemplate.evaluate(writer, context);
+ template.evaluate(writer, (Map) context);
return writer.toString();
}
diff --git a/src/main/java/eu/m724/blog/object/Feed.java b/src/main/java/eu/m724/blog/object/Feed.java
index 64c2378..744748e 100644
--- a/src/main/java/eu/m724/blog/object/Feed.java
+++ b/src/main/java/eu/m724/blog/object/Feed.java
@@ -16,21 +16,21 @@ public class Feed {
* Generates an RSS feed XML string for a given website and its list of blog posts.
*
* @param site the {@code Site} object representing the website for which the RSS feed is generated
* @param posts the list of {@code Post} objects representing the blog posts to include in the RSS feed
* @return a {@code String} containing the formatted RSS feed in XML
*/
- public static String generateRss(Site site, List posts) {
+ public static String generateRss(Site site, List articles) {
var content = new StringBuilder("");
content.append("");
content.append("%s".formatted(site.name()));
content.append("%s".formatted(site.baseUrl()));
- for (var post : posts) {
+ for (var article : articles) {
content.append("- ");
- content.append("%s".formatted(post.title()));
- content.append("%s/post/%s.html".formatted(site.baseUrl(), post.slug()));
- content.append("%s".formatted(post.summary()));
- content.append("%s".formatted(post.createdAt().format(formatter)));
+ content.append("%s".formatted(article.title()));
+ content.append("%s/article/%s.html".formatted(site.baseUrl(), article.slug()));
+ content.append("%s".formatted(article.summary()));
+ content.append("%s".formatted(article.createdAt().format(formatter)));
content.append("
");
}
@@ -16,21 +16,21 @@ public class Feed {
*
* @param site the {@code Site} object representing the website for which the RSS feed is generated
- * @param posts the list of {@code Post} objects representing the blog posts to include in the RSS feed
+ * @param articles the list of {@link Article} objects representing the blog posts to include in the RSS feed
* @return a {@code String} containing the formatted RSS feed in XML
*/